@@ -24,6 +24,12 @@ from .em_block_meta_recorder import __all__ as _em_block_meta_recorder_all
 
 __all__ += _em_block_meta_recorder_all
 
+# import all from submodule em_future_meta_recorder
+from .em_future_meta_recorder import *
+from .em_future_meta_recorder import __all__ as _em_future_meta_recorder_all
+
+__all__ += _em_future_meta_recorder_all
+
 # import all from submodule em_indexus_meta_recorder
 from .em_indexus_meta_recorder import *
 from .em_indexus_meta_recorder import __all__ as _em_indexus_meta_recorder_all
